wagtail-association-panel
=========================

Please bear with us while we prepare more detailed documentation.

Compatibility
-------------

`wagtail-association-panel`' major.minor version number indicates the Wagtail release it is compatible with. Currently this is Wagtail 4.1.x

Installation
------------

1. Install using `pip`:
  ```shell
  pip install wagtail-association-panel
  ```
2. If you use functional that requires an app (such as tags), add
   `wagtail_association_panel` to your `INSTALLED_APPS` setting:
   ```python
   INSTALLED_APPS = [
     # ...
     'wagtail_association_panel'
     # ...
   ]
   ```
